@@ -19,7 +19,8 @@ Note:
 import subprocess
 import shutil
 from pathlib import Path
-from . import misc
+from mypythontools import misc
+import mylogging
 
 
 def build_app(
@@ -87,7 +88,7 @@ def build_app(
 
     if preset == 'eel':
         if not web_path:
-            web_path = misc.find_path('index.html', exclude=['public', 'node_modules', 'build', 'dist']).parent
+            web_path = misc.find_path('index.html', exclude=['public', 'node_modules', 'build']).parent
 
         else:
             web_path = Path(web_path)
@@ -100,12 +101,17 @@ def build_app(
 
         hidden_imports = [*hidden_imports, 'bottle_websocket']
 
-        # TODO
-        # Find by main.js
         datas = tuple([*datas, (web_path.as_posix(), 'gui')])
-        ignored_packages = [*ignored_packages, 'tensorflow', 'keras', 'notebook', 'pytest', 'pyzmq', 'zmq', 'sqlalchemy', 'sphinx', 'PyQt5', 'PIL', 'matplotlib', 'qt5', 'PyQt5', 'qt4', 'pillow']
         env_vars = {**env_vars, 'MY_PYTHON_VUE_ENVIRONMENT': 'production'}
 
+    # Remove last dist manually to avoid permission error if opened in some application
+    dist_path = Path('dist').resolve()
+    if dist_path.exists():
+        try:
+            shutil.rmtree(dist_path, ignore_errors=False)
+        except PermissionError:
+            raise PermissionError(mylogging.return_str("App is opened (May be in another app(terminal, explorer...)). Close it first."))
+
     generated_warning = """
 #########################
 ### File is generated ###
@@ -183,7 +189,6 @@ coll = COLLECT(exe,
     if remove_last_build:
         try:
             shutil.rmtree('build', ignore_errors=True)
-            shutil.rmtree('dist', ignore_errors=True)
         except Exception:
             pass
 
@@ -193,7 +198,10 @@ coll = COLLECT(exe,
         subprocess.run(['npm', 'run', 'build'], shell=True, check=True, cwd=gui_path)
 
     # Build py to exe
-    subprocess.run(['pyinstaller', '-y', spec_path.as_posix()], shell=True, check=True, cwd=main_folder_path)
+    try:
+        subprocess.run(['pyinstaller', '-y', spec_path.as_posix()], shell=True, check=True, cwd=root_path)
+    except PermissionError:
+        raise PermissionError('\n\nYou have to close app and also folders opened in explorer.\n\n')
 
     if cleanit:
         try:
