@@ -39,7 +39,7 @@ def find_path(file, folder=None, exclude=['node_modules', 'build', 'dist'], leve
         FileNotFoundError: If file is not found.
     """
 
-    folder = root_path if not folder else folder
+    folder = root_path if not folder else Path(folder).resolve()
 
     for lev in range(levels):
         glob_file_str = f"{'*/' * lev}{file}"
